<?php

namespace LakeDrops\Drupal8Theme\SASS;

use Composer\Script\Event;
use Composer\Script\ScriptEvents;
use Exception;
use LakeDrops\Component\Composer\BasePlugin;

/**
 * Composer plugin for handling drupal sass theme template.
 */
class Plugin extends BasePlugin {

  /**
   * {@inheritdoc}
   */
  public function getHandlerClass(): string {
    return Handler::class;
  }

  /**
   * {@inheritdoc}
   */
  public function getCapabilities(): array {
    return [
      \Composer\Plugin\Capability\CommandProvider::class => CommandProvider::class,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      ScriptEvents::POST_INSTALL_CMD => 'initThemeEvent',
      ScriptEvents::POST_UPDATE_CMD => 'updateThemeEvent',
    ];
  }

  /**
   * Post package install event callback.
   *
   * @param \Composer\Script\Event $event
   *   The event that triggered the plugin.
   * @throws Exception
   */
  public function initThemeEvent(Event $event): void {
    $this->updateThemeEvent($event, FALSE);
  }

  /**
   * Post package update event callback.
   *
   * @param \Composer\Script\Event $event
   *   The event that triggered the plugin.
   * @param bool $update
   *   Whether to update (TRUE) or initially installing (FALSE).
   * @throws Exception
   */
  public function updateThemeEvent(Event $event, $update = TRUE): void {
    /** @var Handler $handler */
    $handler = $this->handler;
    $handler
      ->setEvent($event)
      ->setUpdate($update)
      ->updateTheme();
  }

}
